@@ -11,7 +11,7 @@ use vipers::prelude::*;
 
 impl MergeMiner {
     /// Initializes a [quarry_mine::Miner] for the [MergeMiner].
-    pub fn init_miner(&self, init: &InitMiner, bump: u8) -> Result<()> {
+    pub fn init_miner(&self, init: &InitMiner) -> Result<()> {
         let seeds = gen_merge_miner_signer_seeds!(self);
         let signer_seeds = &[&seeds[..]];
         let cpi_ctx = CpiContext::new_with_signer(
@@ -19,7 +19,7 @@ impl MergeMiner {
             init.to_create_miner_accounts(),
             signer_seeds,
         );
-        quarry_mine::cpi::create_miner(cpi_ctx, bump)
+        quarry_mine::cpi::create_miner_v2(cpi_ctx)
     }
 
     /// Stakes all available primary tokens owned by the [MergeMiner] into the primary miner.
@@ -157,12 +157,12 @@ impl MergeMiner {
     pub fn claim_rewards(&self, claim: &ClaimRewards) -> Result<()> {
         let seeds = gen_merge_miner_signer_seeds!(self);
         let signer_seeds = &[&seeds[..]];
-        let cpi_ctx: CpiContext<quarry_mine::cpi::accounts::ClaimRewards> =
+        let cpi_ctx: CpiContext<quarry_mine::cpi::accounts::ClaimRewardsV2> =
             CpiContext::new_with_signer(
                 claim.stake.mine_program.to_account_info(),
                 claim.to_claim_rewards_accounts(),
                 signer_seeds,
             );
-        quarry_mine::cpi::claim_rewards(cpi_ctx)
+        quarry_mine::cpi::claim_rewards_v2(cpi_ctx)
     }
 }
